NavigationGraph class final
Immutable application graph shared by one or more sessions.
- Annotations
Constructors
- Creates and validates a graph.
Properties
- defaultPresentation → NavigationPresentation
-
final
-
guards
→ List<
NavigationGuard> -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
modules
→ List<
NavigationModule> -
final
-
mounts
→ List<
NavigationMount> -
final
-
redirects
→ List<
NavigationRedirect> -
final
- revision → int
-
final
- rootScopeId → NavigationScopeId
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
scopes
→ List<
NavigationScopeDefinition> -
final
Methods
-
decode(
Uri uri) → NavigationUriResolution - Decodes an external URI and its deterministic parent stack.
-
edit(
) → NavigationGraphBuilder - Starts an atomic graph edit.
-
module(
NavigationModuleId id) → NavigationModule - Reads a required module.
-
mount(
NavigationMountId id) → NavigationMount - Reads a required mount.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
resolve(
NavigationTarget< Object?> target) → ResolvedNavigationTarget - Resolves a typed destination without using a route-name string.
-
route(
NavigationRouteId id) → NavigationRouteDefinitionBase - Reads a required route definition.
-
scope(
NavigationScopeId id) → NavigationScopeDefinition - Reads a required scope definition.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited