NavigationSurface enum

Visual surface represented by a navigation entry.

Inheritance
Available extensions

Values

page → const NavigationSurface

An opaque page in a Navigator stack.

fullscreenDialog → const NavigationSurface

A platform fullscreen dialog.

A non-opaque modal route with a barrier.

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<NavigationSurface>
A constant List of the values in this enum, in order of their declaration.